@@ -5,9 +5,6 @@ import json
 
 
 class MainPaste:
-    __slots__ = ("sucess", "id", "encrypted", "description",
-                 "views", "created_at", "expires_at",
-                 "sections")
 
     def __init__(self, data: dict):
         self.raw = data
@@ -46,7 +43,6 @@ class MainPaste:
 
 
 class Syntax:
-    __slots__ = ("id", "short", "name")
 
     def __init__(self, context):
         self.raw = context
@@ -68,7 +64,6 @@ class Syntax:
 
 
 class PasteSection:
-    __slots__ = ("name", "syntax", "contents")
 
     def __init__(self, context: dict):
         self.raw = context
@@ -90,7 +85,6 @@ class PasteSection:
 
 
 class PasteFormat:
-    __slots__ = ("name", "syntax", "contents")
 
     def __init__(self, contents: str,
                  name: Optional[str] = "Paste",
@@ -113,8 +107,6 @@ class PasteFormat:
 
 
 class Paste:
-    __slots__ = ("id", "description", "created_at",
-                 "sections")
 
     def __init__(self, context: dict):
         self.raw = context
@@ -127,9 +119,6 @@ class Paste:
 
 
 class PasteResults:
-    __slots__ = ("total", "per_page", "current_page",
-                 "last_page", "next_page_url", "from",
-                 "to", "data")
 
     def __init__(self, paste: dict):
         self.raw = paste
